local _, core = ...
local AltVault = core.AltVault

local updates = {
    {
        version = "1.0.0 - 1.7.0",
        title = "Shadowlands",
    },
}

StaticPopupDialogs["RESET_ADDON_DATA"] = {
    text = "Are you sure you want to reset all AltVault data? This cannot be undone.",
    button1 = "Yes",
    button2 = "No",
    OnAccept = function()
        AltVaultResetData()
    end,
    timeout = 0,
    whileDead = true,
    hideOnEscape = true,
    preferredIndex = 3
}

function AltVaultOptions_OnLoad(frame)
    frame.name = "AltVault"
    local version = GetAddOnMetadata("AltVault", "Version")
    frame.Title:SetText("AltVault v"..version)
    frame.ShowMinimapIcon.Text:SetText("Hide Minimap Button")
    frame.HideGoldValues.Text:SetText("Hide Gold Values")
    frame.ShowTooltipCounts.Text:SetText("Show Tooltip Counts")
    frame.RememberFilter.Text:SetText("Remember Selected Filter")
    InterfaceOptions_AddCategory(frame);
end

function AltVaultOptions_OnShow(frame)
    frame.ShowMinimapIcon:SetChecked(AltVaultDB.minimap.hide ~= false)
    frame.HideGoldValues:SetChecked(AltVaultDB.data.hideGoldValues ~= false)
    frame.ShowTooltipCounts:SetChecked(AltVaultDB.data.showTooltipCounts ~= false)
    frame.RememberFilter:SetChecked(AltVaultDB.data.rememberFilter ~= false)
end

function AltVaultOptionsMM_OnClick()
    if AltVaultDB.minimap.hide == false then 
        AltVaultDB.minimap.hide = true
        LibStub("LibDBIcon-1.0"):Hide("AltVault")
    else
        AltVaultDB.minimap.hide = false
        LibStub("LibDBIcon-1.0"):Show("AltVault")
    end
end

function AltVaultOptionsGold_OnClick()
    if AltVaultDB.data.hideGoldValues == false then
        AltVaultDB.data.hideGoldValues = true
    else
        AltVaultDB.data.hideGoldValues = false
    end
end

function AltVaultOptionsReset_OnClick()
    StaticPopup_Show("RESET_ADDON_DATA")
end

function AltVaultShowTooltipCounts_OnClick()
    if AltVaultDB.data.showTooltipCounts == false then
        AltVaultDB.data.showTooltipCounts = true
    else
        AltVaultDB.data.showTooltipCounts = false
    end
end

function AltVaultRememberFilter_OnClick()
    if AltVaultDB.data.rememberFilter == false then
        AltVaultDB.data.rememberFilter = true
    else
        AltVaultDB.data.rememberFilter = false
    end
end

function AltVaultResetData()
    AltVaultDB = nil
    core:init("PLAYER_LOGIN")
end

function RenderUpdates()
    for i = 1, #updates do
        local update = updates[i];
        local titleString = AltVaultOptions:CreateFontString("UpdateTitle"..i, "ARTWORK", "GameFontHighlightMedium")
        if i == 1 then
            titleString:SetPoint("TOPLEFT", "UpdatesTitle", "BOTTOMLEFT", 10, -10)
        else
            local prevUpdate = updates[i-1]
            if prevUpdate.changes then
                titleString:SetPoint("TOPLEFT", "Update".. i-1 .."Change"..#prevUpdate.changes, "BOTTOMLEFT", -15, -15)
            else
                titleString:SetPoint("TOPLEFT", "UpdateTitle"..i-1, "BOTTOMLEFT", 0, -10)
            end
        end

        local hex = select(4, AltVault:GetThemeColor());
        local prefix = string.format("|cff%s%s|r", hex:upper(), update.version);
        local title = update.title or "Patch"
        titleString:SetText(prefix..": "..title)

        if update.changes then
            for j = 1, #update.changes do
                local change = update.changes[j]
                local changeString = AltVaultOptions:CreateFontString("Update".. i .."Change"..j, "ARTWORK", "GameFontHighlightSmall")
                if j == 1 then
                    changeString:SetPoint("TOPLEFT", "UpdateTitle"..i, "BOTTOMLEFT", 15, -8)
                else
                    changeString:SetPoint("TOPLEFT", "Update".. i .."Change"..j-1, "BOTTOMLEFT", 0, -8)
                end
                changeString:SetText("- "..change)
            end
        end
        
    end
end